DependencyPattern

Enum DependencyPattern 

pub enum DependencyPattern {
    SameFrame,
    Window {
        before: usize,
        after: usize,
    },
    FrameMap(DynamicDependencyBounds),
    Dynamic(DynamicDependencyBounds),
}
Declares which upstream frames a node may request while producing one output frame.

Variants



SameFrame

Input frame must equal output frame.



Window

Input frame may be in [output - before, output + after].

Fields

before: usize

Maximum number of frames allowed before output frame.

after: usize

Maximum number of frames allowed after output frame.



FrameMap(DynamicDependencyBounds)

Input frame is mapped by filter logic but must stay within declared bounds.



Dynamic(DynamicDependencyBounds)

Input frame is chosen at runtime but must stay within declared bounds.

Implementations



impl DependencyPattern

pub const fn same_frame() -> DependencyPattern

Creates same-frame dependency contract.

pub const fn window(before: usize, after: usize) -> DependencyPattern

Creates bounded window dependency contract.

pub const fn frame_map(bounds: DynamicDependencyBounds) -> DependencyPattern

Creates frame-map dependency contract.

pub const fn dynamic(bounds: DynamicDependencyBounds) -> DependencyPattern

Creates dynamic dependency contract.

pub const fn allows(&self, output: usize, requested: usize) -> bool

Returns true when requested frame is allowed for one output frame.