DynamicDependencyBounds

Enum DynamicDependencyBounds 

pub enum DynamicDependencyBounds {
    Any,
    AnyNoReuse,
    PastOnly,
    FutureWindow {
        after: usize,
    },
    Bounded {
        before: usize,
        after: usize,
    },
}
Runtime bounds for frame-map and dynamic dependencies.

Variants



Any

Any frame in finite clip range may be requested.



AnyNoReuse

Any frame in finite clip range may be requested and is not reused by future outputs.



PastOnly

Requested frame must be less than or equal to output frame.



FutureWindow

Requested frame must be in [output, output + after].

Fields

after: usize

Maximum number of frames allowed after output frame.



Bounded

Requested frame must be in [output - before, output + after].

Fields

before: usize

Maximum number of frames allowed before output frame.

after: usize

Maximum number of frames allowed after output frame.

Implementations



impl DynamicDependencyBounds

pub const fn any() -> DynamicDependencyBounds

Creates unbounded dynamic access.

pub const fn any_no_reuse() -> DynamicDependencyBounds

Creates unbounded dynamic access without future input reuse.

pub const fn past_only() -> DynamicDependencyBounds

Creates past-only dynamic access.

pub const fn future_window(after: usize) -> DynamicDependencyBounds

Creates future-window dynamic access.

pub const fn bounded(before: usize, after: usize) -> DynamicDependencyBounds

Creates bounded dynamic access.

pub const fn allows(self, output: usize, requested: usize) -> bool

Returns true when requested frame is allowed for one output frame.