ConcurrencyClass

Enum ConcurrencyClass 

pub enum ConcurrencyClass {
    Stateless,
    OrderedStateful,
    FrameGroupSerial {
        group_size: usize,
        max_active_groups: Option<usize>,
    },
    Source,
}
Declares how scheduler may run node callbacks across frames.

Variants



Stateless

Callback has no cross-frame mutable state.



OrderedStateful

Callback may prepare out of order but must commit in increasing frame order.



FrameGroupSerial

Callback serializes frames that share the same fixed-size output group.

Fields

group_size: usize

Number of output frames per scheduler group. Zero is treated as one.

max_active_groups: Option<usize>

Maximum distinct output groups active at once. None allows unbounded speculation.



Callback is a source and may declare source-specific capability limits.

Implementations



impl ConcurrencyClass

pub const fn frame_group_serial(group_size: usize) -> ConcurrencyClass

Creates a concurrency class that serializes frames in fixed-size output groups.

pub const fn frame_group_serial_unbounded(group_size: usize) -> ConcurrencyClass

Creates grouped serial scheduling without bounding distinct active groups.

pub const fn group_size(self) -> Option<usize>

Returns output group size for grouped serial scheduling.

pub const fn as_str(self) -> &'static str

Returns stable diagnostic name.