ExpansionRequest

Struct ExpansionRequest 

pub struct ExpansionRequest<'a> { /* private fields */ }
Safe expansion request passed to Rust plugin expander callbacks.

Implementations



impl<'a> ExpansionRequest<'a>

pub const fn new( inner: &'a mut FilterExpansionRequest<'a>, ) -> ExpansionRequest<'a>

Creates SDK expansion request from core request.

pub const fn input_clips(&self) -> &[Clip]

Returns input clip handles in call order.

pub const fn input_media(&self) -> &[ClipMedia]

Returns media for all input clips in call order.

pub const fn options(&self) -> &BTreeMap<String, FilterOptionValue>

Returns graph-node options.

pub fn add_private_filter( &mut self, name: &str, inputs: &[Clip], options: BTreeMap<String, FilterOptionValue>, ) -> Result<Clip, PixelFlowError>

Adds one registered private helper filter node to the graph.