Struct MetadataSchema
pub struct MetadataSchema { /* private fields */ }Expand description
Metadata schema for core keys and plugin extension keys.
Implementations
impl MetadataSchema
impl MetadataSchema
pub fn core() -> MetadataSchema
pub fn core() -> MetadataSchema
Creates schema containing all core:* keys.
pub fn register_plugin_key(
&mut self,
key: &str,
kind: MetadataKind,
) -> Result<(), PixelFlowError>
pub fn register_plugin_key( &mut self, key: &str, kind: MetadataKind, ) -> Result<(), PixelFlowError>
Registers a plugin metadata key in publisher/plugin:key format.
pub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true when key is registered in schema.
pub fn kind(&self, key: &str) -> Option<MetadataKind>
pub fn kind(&self, key: &str) -> Option<MetadataKind>
Returns declared metadata kind for registered key.
pub fn is_core_key(&self, key: &str) -> bool
pub fn is_core_key(&self, key: &str) -> bool
Returns true when key is one of built-in core:* keys.
pub fn validate_value(
&self,
key: &str,
value: &MetadataValue,
) -> Result<(), PixelFlowError>
pub fn validate_value( &self, key: &str, value: &MetadataValue, ) -> Result<(), PixelFlowError>
Validates that key is registered and value matches declared kind.