Type Alias ExecutorFactoryCallback
pub type ExecutorFactoryCallback = fn(ExecutorRequest<'_>) -> Result<Box<dyn FrameExecutor>, PixelFlowError>;Expand description
Executor factory callback type used by Rust plugin authors.
pub type ExecutorFactoryCallback = fn(ExecutorRequest<'_>) -> Result<Box<dyn FrameExecutor>, PixelFlowError>;Executor factory callback type used by Rust plugin authors.