Struct ScriptPluginLibrary
pub struct ScriptPluginLibrary { /* private fields */ }Expand description
Validated script plugin library contents plus generated Rhai source.
Implementations
impl ScriptPluginLibrary
impl ScriptPluginLibrary
pub fn functions(&self) -> &[ScriptPluginFunction]
pub fn functions(&self) -> &[ScriptPluginFunction]
Returns loaded script plugin functions in deterministic discovery order.