Struct FilterChangeSet
pub struct FilterChangeSet {
pub format: bool,
pub resolution: bool,
pub frame_count: bool,
pub frame_rate: bool,
}Expand description
Filter output axes that may differ from the first input clip.
Fields
format: boolOutput format may differ from the first input format.
resolution: boolOutput resolution may differ from the first input resolution.
frame_count: boolOutput frame count may differ from the first input frame count.
frame_rate: boolOutput frame rate may differ from the first input frame rate.