Struct GraphNode
pub struct GraphNode { /* private fields */ }Expand description
One immutable graph node.
Implementations
impl GraphNode
impl GraphNode
pub const fn identity(&self) -> GraphNodeIdentity
pub const fn identity(&self) -> GraphNodeIdentity
Returns the node-content identity shared by clones of this graph node.
pub const fn filter_options(
&self,
) -> Option<&BTreeMap<String, FilterOptionValue>>
pub const fn filter_options( &self, ) -> Option<&BTreeMap<String, FilterOptionValue>>
Returns stored filter options when this node is a filter.