Struct PlaneMut
pub struct PlaneMut<'a, T>where
T: Sample,{ /* private fields */ }Expand description
Typed mutable plane view available while building outputs.
Implementations
impl<'a, T> PlaneMut<'a, T>where
T: Sample,
impl<'a, T> PlaneMut<'a, T>where
T: Sample,
pub fn row_bytes_mut(&mut self, row: usize) -> Option<&mut [u8]>
pub fn row_bytes_mut(&mut self, row: usize) -> Option<&mut [u8]>
Returns mutable row slice of raw bytes by row index.
pub fn raw_parts(&mut self) -> RawPlaneMut
pub fn raw_parts(&mut self) -> RawPlaneMut
Returns raw mutable pointer and plane shape for expert code.