Struct Graph
pub struct Graph { /* private fields */ }Expand description
Immutable graph ready for validation and future rendering.
Implementations
impl Graph
impl Graph
pub const fn identity(&self) -> GraphIdentity
pub const fn identity(&self) -> GraphIdentity
Returns the graph node-content identity shared by clones of the same built graph.
pub fn with_source_media(
self,
node_id: NodeId,
media: ClipMedia,
) -> Result<Graph, PixelFlowError>
pub fn with_source_media( self, node_id: NodeId, media: ClipMedia, ) -> Result<Graph, PixelFlowError>
Returns graph clone with one source node media description replaced.
pub fn with_source_capabilities(
self,
node_id: NodeId,
capabilities: SourceCapabilities,
) -> Result<Graph, PixelFlowError>
pub fn with_source_capabilities( self, node_id: NodeId, capabilities: SourceCapabilities, ) -> Result<Graph, PixelFlowError>
Returns graph clone with one source node scheduling capabilities replaced.
pub fn with_replanned_filter_media(
self,
registry: &FilterRegistry,
metadata_schema: &MetadataSchema,
) -> Result<Graph, PixelFlowError>
pub fn with_replanned_filter_media( self, registry: &FilterRegistry, metadata_schema: &MetadataSchema, ) -> Result<Graph, PixelFlowError>
Returns graph with reachable filter plans refreshed from current input media.
pub fn with_single_output(self, output: Clip) -> Result<Graph, PixelFlowError>
pub fn with_single_output(self, output: Clip) -> Result<Graph, PixelFlowError>
Returns a graph clone with exactly one final output clip.
pub fn validation_plan(&self) -> Result<ValidationPlan, PixelFlowError>
pub fn validation_plan(&self) -> Result<ValidationPlan, PixelFlowError>
Finds reachable nodes and sources from single final output.
pub fn validate(&self) -> Result<ValidatedGraph, PixelFlowError>
pub fn validate(&self) -> Result<ValidatedGraph, PixelFlowError>
Validates topology and media constraints for reachable output graph.